import _toConsumableArray from 'babel-runtime/helpers/toConsumableArray';
import _extends from 'babel-runtime/helpers/extends';
import { SagaModel } from 'redux-saga-model';
import { routerMiddleware, routerReducer as routing } from 'react-router-redux';

/**
 * 获取saga model实例化对象
 * @param { object } history 同react-router history
 * @param { object } reducers 为经过combineReducer的reducers
 * @param { any } preloadedState 请参考redux的createStore第二参数
 * @param { array } models 请参考redux-saga-model说明
 * @param { array } plugins 请参考redux-saga-model说明
 */
export default function getSagaModel(history, reducers, preloadedState) {
  var models = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : [];
  var middlewares = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : [];
  var plugins = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : [];

  var initialState = preloadedState;
  var initialReducer = _extends({}, reducers, {
    routing: routing
  });
  var initialMiddleware = [routerMiddleware(history)].concat(_toConsumableArray(middlewares));
  var initialModels = models;
  var sagaModel = new SagaModel({
    initialState: initialState,
    initialReducer: initialReducer,
    initialMiddleware: initialMiddleware,
    initialModels: initialModels,
    history: history
  });
  plugins.forEach(sagaModel.use.bind(sagaModel));
  return sagaModel;
}